@@ -1,7 +1,7 @@
 """Main module."""
 
 from functools import singledispatch
-from typing import List
+from typing import List, Optional
 
 from tasks3.db import Task, session_scope
 
@@ -9,6 +9,47 @@ from sqlalchemy.engine import Engine
 from sqlalchemy.orm import Query
 
 
+def search(
+    db_engine: Engine,
+    id: Optional[str] = None,
+    title: Optional[str] = None,
+    urgency: Optional[int] = None,
+    importance: Optional[int] = None,
+    tags: Optional[List[str]] = None,
+    folder: Optional[str] = None,
+    description: Optional[str] = None,
+) -> List[Task]:
+    """Search for tasks
+
+    :param id: Search for tasks that start with ``id``.
+    :param title: Search for tasks with this substring in title.
+    :param urgency: Search for tasks with this urgency level.
+    :param importance: Search for tasks with this importance level.
+    :param tags: Search for tasks with all these tags.
+    :param folder: Search for tasks under this folder.
+    :param db_engine: Engine for the tasks database.
+    """
+    with session_scope(db_engine) as session:
+        query: Query = Query(Task, session)
+        if urgency:
+            query = query.filter(Task.urgency == urgency)
+        if importance:
+            query = query.filter(Task.importance == importance)
+        if id:
+            query = query.filter(Task.id.contains(id))
+        if title:
+            query = query.filter(Task.title.contains(title))
+        if folder:
+            query = query.filter(Task.folder.like(f"{folder}%"))
+        if description:
+            query = query.filter(Task.description.contains(description))
+        results = query.order_by(Task.urgency, Task.importance).all()
+        results.reverse()
+        if tags:
+            results = [task for task in results if set(tags) <= set(task.tags)]
+        return results
+
+
 @singledispatch
 def add(
     title: str,
